==> qwik_0.8.2.orig.tar.gz: qwik-0.8.2.orig/lib/qwik/catalog-ja.rb <==
module Qwik; end

class Qwik::CatalogFactory
  def self.catalog_ja
    {
      # for test
      'hello' => 'ɂ',

      # Error
      'Error' => 'G[',
      'Failed' => 's',
      'No message' => 'bZ[W܂',
      'No text' => 'eLXg܂',

      # action.rb
      'No such site' => 'ΉTCg܂',
      'no correspond site' => 'ΉTCg͂܂',
      'Please send mail to make a site' =>
      'qwikWeb̃TCgɂ́A܂[𑗂Kv܂B',
      'Login' => 'OC',
      'Access here and see how to.' => 'ɃANZXāAgB',
      'Please login.' => 'OCĂ',
      'Member Only' => 'o[p',
      'You are now logged in as this user id.' =>
      'Ȃ͍̃[UIDŃOCĂ܂',
      'You are now logged in yet.' =>
      'Ȃ͂܂OCĂ܂',
      'If you would like to login as another account,' =>
      'ʂ̃[UIDŃOCȂꍇ́A',
      'do logout at the first.' => '܂OAEgĂ',
      ': access here, and login again.' =>
      'ĂēxANZXĂB',
      'You need login to use this function.' =>
      '̋@\𗘗pɂ̓OCKv܂B',
      'Go back' => '߂',
      'Need POST' => 'POST͂Kv',
      'This function needs POST method.' =>
      '̑POST͂ōsKv܂B',
      'Page not found.' => 'y[W܂',
      "Push create if you'd like to create the page." =>
      'y[W쐬ꍇ́AVK쐬Ă',

      'Require no path args' => 'ςȃpXĂ܂',
      'Path argments are not acceptable.' =>
      'ȂɂςȃpXĂ܂B',

      'Not found.' => '܂',
      'Access here.' => 'B',

      # act-album
      'Show album in fullscreen.' => 'AotXN[Ō',

      # act-archive
      'site archive' => 'TCgA[JCu',

      # act-attach
      'Files' => 'Ytt@C',
      'del' => '',
      'download' => '_E[h',
      'No such file' => 't@C܂',
      'There is a file with same file name.' =>
      '̃t@C݂Ă܂',
      'Can not use Japanese character for file name' =>
      '{̃t@C͎g܂',
      'The file is saved.' => 't@CZ[u܂B',
      'Attach file done' => 't@CYt܂',
      'Attach file' => 't@CYt',
      'Attach a file' => 't@CYt܂',
      'Confirm to delete a file' => 't@CmF',
      "Push 'Delete' to delete a file" =>
      'uvƁC{Ƀt@C܂D',
      'Delete' => '',
      'Already deleted.' => 'łɏĂ悤ł',
      'Failed to delete.' => 't@CɎs܂BB',
      'The file is deleted.' => '܂',
      'File list' => 'ݓYtĂt@C',
      # other
      '->' => '',
      'attach' => 'Yt',

      # act-backup
      'The first page.' => '͍ŏ̃y[WłB',
      'Diff from the previous page' => 'O񂩂̍',
      'Original data' => 'f[^',
      '<-' => '',
      'newest' => 'ŐV',
      'backup list' => 'obNAbvꗗ',

      # act-basic-plugin
      'newpage' => 'VK쐬',
      'edit' => 'ҏW',
      'wysiwyg' => '̏ŕҏW',
      'Last modified' => 'ŏIXV',
      'Generate time' => '',
      'sec.' => 'b',
      'SiteMenu' => 'TCgj[',
      'SiteConfig' => 'TCgݒ',
      'TimeLine' => 'N\ ',
      'Group members' => 'O[vo[',
      'SiteArchive' => 'TCgA[JCu',
      'ML Config' => '[OXgݒ',

      'Functions' => '@\̐',
      'Page List' => 'y[Wꗗ',
      'Recent Changes' => 'XV',
      ' ago' => 'O',
      'more...' => 'ƑȌ',
      'min.' => '',
      'hour' => '',
      'day' => '',
      'month' => '',
      'year' => 'N',
      'century' => 'I',

      # act-comment
      'User' => '[U',
      'Message' => 'bZ[W',
      'Message is added.' => 'bZ[Wǉ܂',

      # act-config
      'Site config'	=> 'TCgݒ',

      # act-chronology
      'Time walker' => 'ԗs',
      'Chronology' => ' N\ ',

      # act-day
      'A day' => '',

      # act-describe
      'Function' => '@\',
      'Functions list' => '@\ꗗ',

      # act-edit.rb
      'Page is deleted.' => 'y[W폜܂',
      'Password does not match.' => 'pX[hv܂łB',
      'Password' => 'pX[h',
      'Please find a line like above, then input password in parentheses.' =>
      '̂悤ȍsTāAʂ̒ɃpX[h͂ĂB',

      'Page edit conflict' => 'XVՓ˂܂B',
      'Please save the following content to your text editor.' =>
      'L̓eeLXgGfB^ȂǂɕۑA',
      'Newest page' => 'ŐṼy[W',
      ': see this page and re-edit again.' => 'QƌɍĕҏWĂB',
      'Page is saved.' => 'y[Wۑ܂B',

      'Save' => 'ۑ',
      'Attach' => 'Yt',

      'Edit' => 'ҏW',
      'Attach Files' => 't@CYt',
      'Attach many files' => 'ƂYt',

      'Help' => 'wv',
      'How to qwikWeb' => 'qwikWeb̎g',

      'Site admin' => 'TCgǗ',

      'Header' => 'o',
      'List' => 'ӏ ',
      'Ordered list' => 'Xg ',
      'Blockquote' => 'p ',
      'Word' => '`',
      'Definition' => 't̒` ',
      'Table' => '\ ',
      'Emphasis' => '',
      'Strong' => 'Ƌ',
      'Link' => 'N',
      'more help' => 'Əڂ',

      'Text Format' => 'ꗗ',
      'History' => '',
      'Backup' => 'obNAbv',
      'Time machine' => '^C}V[',
#      'Experimental functions' => '̋@\ ',
      'Page functions' => 'y[W̋@\ ',

      # act-getpass
      'Invalid mail address' => 'pX[h`G[',
      'Get Password' => 'pX[h',
      'Send Password' => 'pX[hM',
      'You will get the password by e-mail.' => 'pX[h[ő܂',
      'Please input your mail address.' => '[AhX͂Ă',
      'Mail address' => '[AhX',
      'Go back to Login' => 'OCʂɂǂ',

      'Send' => 'M',

      'You input this e-mail address as user id.' =>
      'Ȃ̓[UIDƂẴ[AhX͂܂',
      'This user id is not a member of this group.' =>
      '̃[UID́ÃO[vɂ͊܂܂Ă܂',
      'Only the member of this group can get password.' =>
      '̃O[ṽo[́ApX[h擾ł܂B',

      'Your password on' => 'pX[h :',
      'This is your user name and the password on ' =>
      '̃TCgɂ郆[UƃpX[hł : ',
      'Username' => '[U',
      'Password' => 'pX[h',
      'Please access login page on' =>
      'OCy[WɃANZXĂ :',
      'You can input user and pass from this URL automatically.' =>
      'LURLɃANZXƁAIɃ[U[ƃpX[h͂܂B',

      'The mail address format is wrong.' =>
      '[AhX̌`ԈĂ܂B',
      'Please confirm the input again.' => 'x͂mFĂB',
      'Please access again.' => 'ēxANZXĂB',
      'Send Password Error' => '[MG[',
      'Send failed for system error.' =>
      'VXeG[̂߁ApX[hMɎs܂B',
      'Please contact administrator.' => 'VXeǗ҂ɂAB',

      'Send Password done' => 'pX[hM',
      'I send the password to this mail address.' =>
      'pX[hȉ̃[AhXɑM܂B',
      'Please check your mailbox.' => '[{bNXmFĂ',

      # act-group
      'Member list' => 'o[ꗗ',

      # act-hcomment
      'Name' => 'O',
      'Comment' => 'Rg',
      'Anonymous' => '',
      'Add a comment.' => 'Rgǉ܂',
      'Submit' => 'e',
      'Page collision is detected.' => 'XVՓ˂܂',
      'Go back and input again.' => '̃y[Wɖ߂Aēx͂ĂB',

      # act-history
      'Time machine' => '^C}V[',
      'Move this' => '𓮂ĉ',

      # act-license
      'You can use the files on this site under [[Creative Commons by 2.1|http://creativecommons.org/licenses/by/2.1/jp/]] license.' =>
      'ɒuꂽt@ĆA[[NGCeBuERYA 2.1|http://creativecommons.org/licenses/by/2.1/jp/]]CZX̉ɗpł܂B',
      'You can use the files on this site under [[Creative Commons Attribution-ShareAlike 2.5|http://creativecommons.org/licenses/by-sa/2.5/]] license.' =>
      'ɒuꂽt@ĆA[[NGCeBuERY A -  2.5|http://creativecommons.org/licenses/by-sa/2.5/]]CZX̉ɗpł܂B',
      'The files you uploaded will be under [[Creative Commons Attribution-ShareAlike 2.5|http://creativecommons.org/licenses/by-sa/2.5/]] license.' =>
      'ɃAbv[hꂽt@ĆA[[NGCeBuERY A -  2.5|http://creativecommons.org/licenses/by-sa/2.5/]]CZX̉ɒu܂B',

      # act-login
      'Logout' => 'OAEg',
      'Login by Session' => 'Sessionɂ郍OC',
      'succeed' => '',
      'Go next' => '',
      'Session ID Auth' => 'Session IDF',
      'or, Access here.' => '܂́ApB',
      'Login by using Basic Auth.' => 'BasicF؂ŃOC܂B',
      'Login by Basic Auth' => 'BasicF؂ŃOC',
      'Do login by Basic Auth.' => 'BasicF؂ŃOC܂B',
      'Login by cookie' => 'cookieɂ郍OC',
      'You are already login by cookie.' => 'cookieŃOCĂ܂B',

      'Login Error' => 'OCG[',
      'Invalid ID(E-mail) or Password.' =>
      '[UID(E-mail)̓pX[hႢ܂',

      'Already logged in' => 'OCς',

      'Please confirm the mail again.' =>
      '͂ɊԈႢȂǂx[mFB',
      '(Please do not use copy & paste.  Please input the password from keryboard again.)' => '(Rs[&y[XgƃG[ɂȂꍇ܂B̏ꍇ͂萔łL[{[h͂Ă݂Ă)',
      'Can not logout.' => 'OAEgł܂',
      'You can not logout in Basic Auth mode.' =>
      'BasicF؂̏ꍇ̓OAEgł܂B',
      'Please close browser and access again.' =>
      'UuEUāAēxANZXĂB',
      'Terminal Number is deleted.' => '[ԍ폜܂',
      'Basic Auth' => 'BasicF',
      'For mobile phone user' => 'gѓdb͂̕',
      'Logout done.' => 'OAEg',
      'Confirm' => 'mF',
      "Push \"Do Logout\"." =>
      'uOAEgvƁA{ɃOAEg܂B',
      'Do Logout' => 'OAEg',

      'Login to ' => 'OC܂ : ',
      'Please input ID(E-mail) and password.' =>
      '[UIDƃpX[h͂Ă',
      'ID' => '[UID',
      'Password' => 'pX[h',

      "If you don't have password, " => 'pX[hłȂ',
      'access here' => '',
      "If you don't have password" => 'pX[h܂ĂȂ?',
      'For mobile phone user, please use' =>
      'gѓdb́̕Ap',
      'You can also use TypeKey' => 'TypeKeyg܂',
      'Login by TypeKey' => 'TypeKeyŃOC',

      # act-member
      'Add a member' => 'o[ǉ',
      'Mail address to add' => 'ǉ郁[AhX',
      'Add' => 'ǉ',
      'Invalid Mail' => 'ȃ[AhX',
      'Already exist' => 'łɑ݂Ă܂',
      'Member added' => 'o[͒ǉ܂',
      'Member list' => 'o[ꗗ',
      'Member' => 'o[',

      # act-mlsubmitform
      'Mlcommit' => 'eB',

      # act-pagelist
      'Recent change' => 'ŐV̍XV',

      # act-plan
      'Plan' => '\',
      'New plan' => 'V\',
      'Create a new plan' => 'V\̓o^',

      # act-schedule
      'Schedule' => 'XPW[',
      'Date' => 't',
      'Schedule edit done.' => 'XPW[͂܂B',

      # act-slogin
      'Session ID is registerd.' => 'Session IDo^܂B',

      # act-style
      'Access Failed' => 'ANZXł܂ł',

      # act-map
      'Show map in fullscreen.' => 'n}tXN[Ō',

      # act-mcomment
      'Failed' => 's܂',

      # act-mdlb
      'Please specify file.' => 't@Cw肵ĂB',
      'Please contact the administrator.' => 'Ǘ҂ɘAĂB',
      'The file is saved as this filename.' =>
      '̃t@CŃZ[u܂B',
      'The image is also saved.' =>
      '摜t@CZ[u܂B',
      'Model file' => 'ft@C',
      'Image file' => '摜t@C',

      # act-mdblb-model
#      'Title' => '^Cg',
      'Author' => '',
#      'Comment' => 'Rg',
      'Download' => '_E[h',

      # act-new
      'Push create.' => 'VK쐬ĂB',
      'New page' => 'VK쐬',
      'Title' => '^Cg',
      'PageKey' => 'y[WL[',
      'Already exist' => 'łɑ݂Ă܂',
      ' is already exist.' => '͂łɑ݂Ă܂B',
      'Please specify another title.' => 'Ⴄ^Cgw肵ĂB',
      'Created.' => '쐬܂',
      'Edit new page' => 'VKy[WҏW',

      # etc.
      'Show history' => 'ߋ̕ϑJH',
      'Show backup' => '܂܂ł̗',

      # act-presen
      'Presentation mode' => 'v[[h',
      # other
      'Presen' => 'v[',
      'presentation' => 'v[e[V',

      # act-search
      'Search' => '',
      'Search result' => '',
      'No match.' => '܂łB',

      # act-table-edit
      'You can only use a table.' => 'tableg܂B',
      'You can only use text.' => 'textg܂B',
      'Update' => 'XV',
      'Edit done.' => 'ҏW',

      # act-textarea
      'Edit text done.' => 'eLXgҏW܂',

      # act-takahashi
      'Show in fullscreen.' => 'tXN[Ō',

      # act-toc
      'contents' => 'ڎ',

      # act-typekey
      'Can not use.' => 'g܂B',
      'Verify failed.' => 'F؂ł܂łB',
      'Time out.' => 'Ԑ؂łB',

      # act-wysiwyg
      'Edit in this page' => '̏ŕҏW',
      'Auto save' => 'ۑ',
      'This is experimental function.' => '̋@\͂܂łB',
      'The contents will be translated to html.' =>
      'y[W̓éASHTMLɕϊ܂B',
      'Please use this function only if you understand what will happen.' =>
      'N̂𗝉Ăꍇ̂݁AgB',

      # act-wema
      'How to Post-it' => 'Ⳃ̎g',
      'New post-it is created.' => 'tⳂVKɍ쐬܂',
      'Edit done.' => 'ҏW܂',
      'No action.' => '܂ł',
      'Delete a Post-it.' => 'tⳂ܂',
      'Set position.' => 'ʒuZbg܂',
      'Post-it' => '',
      'New Post-it' => 'VK',
      'help' => 'g',
      'Draw Line' => '',
      'Text color' => 'F',
      'Background' => 'wiF',

      # Add you catalog here.
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
    }
  end
end

==> qwik_0.8.4.4.tar.gz: qwik-0.8.4.4/lib/qwik/catalog-ja.rb <==
# Copyright (C) 2003-2006 Kouichirou Eto, All rights reserved.
# This is free software with ABSOLUTELY NO WARRANTY.
# You can redistribute it and/or modify it under the terms of the GNU GPL 2.

module Qwik; end

class Qwik::CatalogFactory
  def self.catalog_ja
    {
      # for test
      'hello' => 'ɂ',

      # Error
      'Error' => 'G[',
      'Failed' => 's',
      'No message' => 'bZ[W܂',
      'No text' => 'eLXg܂',

      # action.rb
      'No such site' => 'ΉTCg܂',
      'no correspond site' => 'ΉTCg͂܂',
      'Please send mail to make a site' =>
      'qwikWeb̃TCgɂ́A܂[𑗂Kv܂B',
      'Login' => 'OC',
      'Access here and see how to.' => 'ɃANZXāAgB',
      'Please login.' => 'OCĂ',
      'Member Only' => 'o[p',
      'You are now logged in as this user id.' =>
      'Ȃ͍̃[UIDŃOCĂ܂',
      'You are now logged in yet.' =>
      'Ȃ͂܂OCĂ܂',
      'If you would like to login as another account,' =>
      'ʂ̃[UIDŃOCȂꍇ́A',
      'do logout at the first.' => '܂OAEgĂ',
      ': access here, and login again.' =>
      'ĂēxANZXĂB',
      'You need login to use this function.' =>
      '̋@\𗘗pɂ̓OCKv܂B',
      'Go back' => '߂',
      'Need POST' => 'POST͂Kv',
      'This function needs POST method.' =>
      '̑POST͂ōsKv܂B',
      'Page not found.' => 'y[W܂',
      "Push create if you'd like to create the page." =>
      'y[W쐬ꍇ́AVK쐬Ă',

      'Require no path args' => 'ςȃpXĂ܂',
      'Path argments are not acceptable.' =>
      'ȂɂςȃpXĂ܂B',

      'Not found.' => '܂',
      'Access here.' => 'B',

      # act-album
      'Show album in fullscreen.' => 'AotXN[Ō',

      # act-archive
      'site archive' => 'TCgA[JCu',

      # act-attach
      'Files' => 'Ytt@C',
      'del' => '',
      'download' => '_E[h',
      'No such file' => 't@C܂',
      'There is a file with same file name.' =>
      '̃t@C݂Ă܂',
      'Can not use Japanese character for file name' =>
      '{̃t@C͎g܂',
      'The file is saved.' => 't@CZ[u܂B',
      'Attach file done' => 't@CYt܂',
      'Attach file' => 't@CYt',
      'Attach a file' => 't@CYt܂',
      'Confirm to delete a file' => 't@CmF',
      "Push 'Delete' to delete a file" =>
      'uvƁC{Ƀt@C܂D',
      'Delete' => '',
      'Already deleted.' => 'łɏĂ悤ł',
      'Failed to delete.' => 't@CɎs܂BB',
      'The file is deleted.' => '܂',
      'File list' => 'ݓYtĂt@C',
      # other
      '->' => '',
      'attach' => 'Yt',

      # act-backup
      'The first page.' => '͍ŏ̃y[WłB',
      'Diff from the previous page' => 'O񂩂̍',
      'Original data' => 'f[^',
      '<-' => '',
      'newest' => 'ŐV',
      'backup list' => 'obNAbvꗗ',

      # act-basic-plugin
      'newpage' => 'VK쐬',
      'edit' => 'ҏW',
      'wysiwyg' => '̏ŕҏW',
      'Last modified' => 'ŏIXV',
      'Generate time' => '',
      'sec.' => 'b',
      'SiteMenu' => 'TCgj[',
      'SiteConfig' => 'TCgݒ',
      'TimeLine' => 'N\ ',
      'Group members' => 'O[vo[',
      'SiteArchive' => 'TCgA[JCu',
      'ML Config' => '[OXgݒ',

      'Functions' => '@\̐',
      'Page List' => 'y[Wꗗ',
      'Recent Changes' => 'XV',
      ' ago' => 'O',
      'more...' => 'ƑȌ',
      'min.' => '',
      'hour' => '',
      'day' => '',
      'month' => '',
      'year' => 'N',
      'century' => 'I',

      # act-comment
      'User' => '[U',
      'Message' => 'bZ[W',
      'Message is added.' => 'bZ[Wǉ܂',

      # act-config
      'Site config'	=> 'TCgݒ',

      # act-chronology
      'Time walker' => 'ԗs',
      'Chronology' => ' N\ ',

      # act-day
      'A day' => '',

      # act-describe
      'Function' => '@\',
      'Functions list' => '@\ꗗ',

      # act-edit.rb
      'Page is deleted.' => 'y[W폜܂',
      'Password does not match.' => 'pX[hv܂łB',
      'Password' => 'pX[h',
      'Please find a line like above, then input password in parentheses.' =>
      '̂悤ȍsTāAʂ̒ɃpX[h͂ĂB',

      'Page edit conflict' => 'XVՓ˂܂B',
      'Please save the following content to your text editor.' =>
      'L̓eeLXgGfB^ȂǂɕۑA',
      'Newest page' => 'ŐṼy[W',
      ': see this page and re-edit again.' => 'QƌɍĕҏWĂB',
      'Page is saved.' => 'y[Wۑ܂B',

      'Save' => 'ۑ',
      'Attach' => 'Yt',

      'Edit' => 'ҏW',
      'Attach Files' => 't@CYt',
      'Attach many files' => 'ƂYt',

      'Help' => 'wv',
      'How to qwikWeb' => 'qwikWeb̎g',

      'Site admin' => 'TCgǗ',

      'Header' => 'o',
      'List' => 'ӏ ',
      'Ordered list' => 'Xg ',
      'Blockquote' => 'p ',
      'Word' => '`',
      'Definition' => 't̒` ',
      'Table' => '\ ',
      'Emphasis' => '',
      'Strong' => 'Ƌ',
      'Link' => 'N',
      'more help' => 'Əڂ',

      'Text Format' => 'ꗗ',
      'History' => '',
      'Backup' => 'obNAbv',
      'Time machine' => '^C}V[',
#      'Experimental functions' => '̋@\ ',
      'Page functions' => 'y[W̋@\ ',

      # act-getpass
      'Invalid mail address' => 'pX[h`G[',
      'Get Password' => 'pX[h',
      'Send Password' => 'pX[hM',
      'You will get the password by e-mail.' => 'pX[h[ő܂',
      'Please input your mail address.' => '[AhX͂Ă',
#      'You can send password for members.' =>
#      'o[ɃpX[h𑗂邱Ƃł܂B',
      'Mail address' => '[AhX',
      'Go back to Login' => 'OCʂɂǂ',

      'Send' => 'M',

      'You input this e-mail address as user id.' =>
      'Ȃ̓[UIDƂẴ[AhX͂܂',
      'This user id is not a member of this group.' =>
      '̃[UID́ÃO[vɂ͊܂܂Ă܂',
      'Only the member of this group can get password.' =>
      '̃O[ṽo[́ApX[h擾ł܂B',

      'Your password on' => 'pX[h :',
      'This is your user name and the password on ' =>
      '̃TCgɂ郆[UƃpX[hł : ',
      'Username' => '[U',
      'Password' => 'pX[h',
      'Please access login page on' =>
      'OCy[WɃANZXĂ :',
      'You can input user and pass from this URL automatically.' =>
      'LURLɃANZXƁAIɃ[U[ƃpX[h͂܂B',

      'The mail address format is wrong.' =>
      '[AhX̌`ԈĂ܂B',
      'Please confirm the input again.' => 'x͂mFĂB',
      'Please access again.' => 'ēxANZXĂB',
      'Send Password Error' => '[MG[',
      'Send failed for system error.' =>
      'VXeG[̂߁ApX[hMɎs܂B',
      'Please contact administrator.' => 'VXeǗ҂ɂAB',

      'Send Password done' => 'pX[hM',
      'I send the password to this mail address.' =>
      'pX[hȉ̃[AhXɑM܂B',
      'Please check your mailbox.' => '[{bNXmFĂ',

      # act-group
      'Member list' => 'o[ꗗ',

      # act-hcomment
      'Name' => 'O',
      'Comment' => 'Rg',
      'Anonymous' => '',
      'Add a comment.' => 'Rgǉ܂',
      'Submit' => 'e',
      'Page collision is detected.' => 'XVՓ˂܂',
      'Go back and input again.' => '̃y[Wɖ߂Aēx͂ĂB',

      # act-history
      'Time machine' => '^C}V[',
      'Move this' => '𓮂ĉ',

      # act-license
      'You can use the files on this site under [[Creative Commons by 2.1|http://creativecommons.org/licenses/by/2.1/jp/]] license.' =>
      'ɒuꂽt@ĆA[[NGCeBuERYA 2.1|http://creativecommons.org/licenses/by/2.1/jp/]]CZX̉ɗpł܂B',
      'You can use the files on this site under [[Creative Commons Attribution-ShareAlike 2.5|http://creativecommons.org/licenses/by-sa/2.5/]] license.' =>
      'ɒuꂽt@ĆA[[NGCeBuERY A -  2.5|http://creativecommons.org/licenses/by-sa/2.5/]]CZX̉ɗpł܂B',
      'The files you uploaded will be under [[Creative Commons Attribution-ShareAlike 2.5|http://creativecommons.org/licenses/by-sa/2.5/]] license.' =>
      'ɃAbv[hꂽt@ĆA[[NGCeBuERY A -  2.5|http://creativecommons.org/licenses/by-sa/2.5/]]CZX̉ɒu܂B',

      # act-login
      'Logout' => 'OAEg',
      'Login by Session' => 'Sessionɂ郍OC',
      'succeed' => '',
      'Go next' => '',
      'Session ID Auth' => 'Session IDF',
      'or, Access here.' => '܂́ApB',
      'Login by using Basic Auth.' => 'BasicF؂ŃOC܂B',
      'Login by Basic Auth' => 'BasicF؂ŃOC',
      'Do login by Basic Auth.' => 'BasicF؂ŃOC܂B',
      'Login by cookie' => 'cookieɂ郍OC',
      'You are already login by cookie.' => 'cookieŃOCĂ܂B',
      'You can login by TypeKey.' => 'TypeKeyłOCł܂B',
      'Login Error' => 'OCG[',
      'Invalid ID(E-mail) or Password.' =>
      '[UID(E-mail)̓pX[hႢ܂',

      'Already logged in' => 'OCς',

      'Please confirm the mail again.' =>
      '͂ɊԈႢȂǂx[mFB',
      '(Please do not use copy & paste.  Please input the password from keryboard again.)' => '(Rs[&y[XgƃG[ɂȂꍇ܂B̏ꍇ͂萔łL[{[h͂Ă݂Ă)',
      'Can not logout.' => 'OAEgł܂',
      'You can not logout in Basic Auth mode.' =>
      'BasicF؂̏ꍇ̓OAEgł܂B',
      'Please close browser and access again.' =>
      'UuEUāAēxANZXĂB',
      'Terminal Number is deleted.' => '[ԍ폜܂',
      'Basic Auth' => 'BasicF',
      'For mobile phone user' => 'gѓdb͂̕',
      'Logout done.' => 'OAEg',
      'Confirm' => 'mF',
      "Push \"Do Logout\"." =>
      'uOAEgvƁA{ɃOAEg܂B',
      'Do Logout' => 'OAEg',

      'Login to ' => 'OC܂ : ',
      'Please input ID(E-mail) and password.' =>
      '[UIDƃpX[h͂Ă',
      'ID' => '[UID',
      'Password' => 'pX[h',

      "If you don't have password, " => 'pX[hłȂ',
      'access here' => '',
      "If you don't have password" => 'pX[h܂ĂȂ?',
      'For mobile phone user, please use' =>
      'gѓdb́̕Ap',
      'You can also use TypeKey' => 'TypeKeyg܂',
      'Login by TypeKey' => 'TypeKeyŃOC',
      'Please send mail address for authentication.' =>
      'F؂̂߁A[AhX𑗐MĂ',

      # act-member
      'Add a member' => 'o[ǉ',
      'Mail address to add' => 'ǉ郁[AhX',
      'Add' => 'ǉ',
      'Invalid Mail' => 'ȃ[AhX',
      'Already exist' => 'łɑ݂Ă܂',
      'Member added' => 'o[͒ǉ܂',
      'Member list' => 'o[ꗗ',
      'Member' => 'o[',

      # act-mlsubmitform
      'Mlcommit' => 'eB',

      # act-pagelist
      'Recent change' => 'ŐV̍XV',

      # act-plan
      'Plan' => '\',
      'New plan' => 'V\',
      'Create a new plan' => 'V\̓o^',
      'Please input like this' => '̂悤ɓ͂Ă',
      'Already Exist.' => 'łɂ܂',

      # act-schedule
      'Schedule' => 'XPW[',
      'Date' => 't',
      'Schedule edit done.' => 'XPW[͂܂B',

      # act-slogin
      'Session ID is registerd.' => 'Session IDo^܂B',

      # act-style
      'Access Failed' => 'ANZXł܂ł',

      # act-map
      'Show map in fullscreen.' => 'n}tXN[Ō',

      # act-mcomment
      'Failed' => 's܂',

      # act-mdlb
      'Please specify file.' => 't@Cw肵ĂB',
      'Please contact the administrator.' => 'Ǘ҂ɘAĂB',
      'The file is saved as this filename.' =>
      '̃t@CŃZ[u܂B',
      'The image is also saved.' =>
      '摜t@CZ[u܂B',
      'Model file' => 'ft@C',
      'Image file' => '摜t@C',

      # act-mdblb-model
#      'Title' => '^Cg',
      'Author' => '',
#      'Comment' => 'Rg',
      'Download' => '_E[h',

      # act-new
      'Push create.' => 'VK쐬ĂB',
      'New page' => 'VK쐬',
      'Title' => '^Cg',
      'PageKey' => 'y[WL[',
      'Already exist' => 'łɑ݂Ă܂',
      ' is already exist.' => '͂łɑ݂Ă܂B',
      'Please specify another title.' => 'Ⴄ^Cgw肵ĂB',
      'Created.' => '쐬܂',
      'Edit new page' => 'VKy[WҏW',

      # etc.
      'Show history' => 'ߋ̕ϑJH',
      'Show backup' => '܂܂ł̗',

      # act-presen
      'Presentation mode' => 'v[[h',
      # other
      'Presen' => 'v[',
      'presentation' => 'v[e[V',

      # act-search
      'Search' => '',
      'Search result' => '',
      'No match.' => '܂łB',

      # act-sendpass
      'Success' => '܂',
#      'Failed' => 's܂',
      'Wrong format' => '`Ⴂ܂',
      'Not a member' => 'o[ł͂܂',
      'You can send password for the members.' =>
      'o[ɃpX[h𑗐M邱Ƃł܂B',
      'Please select members to send password.' =>
      'pX[h𑗂郁o[IĂB',

      # act-table-edit
      'You can only use a table.' => 'tableg܂B',
      'You can only use text.' => 'textg܂B',
      'Update' => 'XV',
      'Edit done.' => 'ҏW',

      # act-textarea
      'Edit text done.' => 'eLXgҏW܂',

      # act-takahashi
      'Show in fullscreen.' => 'tXN[Ō',

      # act-toc
      'contents' => 'ڎ',

      # act-typekey
      'Can not use.' => 'g܂B',
      'There is no site token for TypeKey.' =>
      'TypeKeyp̃TCgg[N܂B',
      'Verify failed.' => 'F؂ł܂łB',
      'Time out.' => 'Ԑ؂łB',

      # act-wysiwyg
      'Edit in this page' => '̏ŕҏW',
      'Auto save' => 'ۑ',
      'This is experimental function.' => '̋@\͂܂łB',
      'The contents will be translated to html.' =>
      'y[W̓éASHTMLɕϊ܂B',
      'Please use this function only if you understand what will happen.' =>
      'N̂𗝉Ăꍇ̂݁AgB',

      # act-wema
      'How to Post-it' => 'Ⳃ̎g',
      'New post-it is created.' => 'tⳂVKɍ쐬܂',
      'Edit done.' => 'ҏW܂',
      'No action.' => '܂ł',
      'Delete a Post-it.' => 'tⳂ܂',
      'Set position.' => 'ʒuZbg܂',
      'Post-it' => '',
      'New Post-it' => 'VK',
      'help' => 'g',
      'Draw Line' => '',
      'Text color' => 'F',
      'Background' => 'wiF',

      # Add you catalog here.
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
      '' => '',
    }
  end
end
